LpRegularizer
=============

.. currentmodule:: pykeen.regularizers

.. autoclass:: LpRegularizer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LpRegularizer.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~LpRegularizer.forward

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: forward
